==> v1.2019.5.tar.gz: plantuml/src/net/sourceforge/plantuml/tim/ConditionalContext.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 *
 * If you like this project or if you find it useful, you can support us at:
 *
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 *
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 */
package net.sourceforge.plantuml.tim;

public class ConditionalContext {

	private boolean isTrue;

	private ConditionalContext(boolean isTrue) {
		this.isTrue = isTrue;
	}

	public static ConditionalContext fromValue(boolean isTrue) {
		return new ConditionalContext(isTrue);
	}

	public boolean conditionIsOkHere() {
		return isTrue;
	}

	public void nowInElse() {
		this.isTrue = !isTrue;
	}

}

==> v1.2019.11.tar.gz: plantuml/src/net/sourceforge/plantuml/tim/ConditionalContext.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 *
 * If you like this project or if you find it useful, you can support us at:
 *
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 *
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 *
 */
package net.sourceforge.plantuml.tim;

public class ConditionalContext {

	private boolean isTrue;
	private boolean hasBeenBurn;

	private ConditionalContext(boolean isTrue) {
		this.isTrue = isTrue;
		if (this.isTrue) {
			hasBeenBurn = true;
		}
	}

	public static ConditionalContext fromValue(boolean isTrue) {
		return new ConditionalContext(isTrue);
	}

	public boolean conditionIsOkHere() {
		return isTrue;
	}

	public void enteringElseIf() {
		this.isTrue = false;
	}

	public void nowInElse() {
		this.isTrue = !hasBeenBurn;
	}

	public void nowInSomeElseIf() {
		this.isTrue = true;
		this.hasBeenBurn = true;
	}

	public final boolean hasBeenBurn() {
		return hasBeenBurn;
	}

	public final void setHasBeenBurn(boolean hasBeenBurn) {
		this.hasBeenBurn = hasBeenBurn;
	}

}
